@@ -2,12 +2,10 @@ use strict;
 use warnings;
 
 package namespace::autoclean;
-BEGIN {
-  $namespace::autoclean::AUTHORITY = 'cpan:FLORA';
-}
-# git description: 0.17-8-gc39fcbd
-$namespace::autoclean::VERSION = '0.18';
+# git description: 0.20-6-g216bc1b
+$namespace::autoclean::VERSION = '0.21';
 # ABSTRACT: Keep imports out of your namespace
+# KEYWORDS: namespaces clean dirty imports exports subroutines methods development
 
 use B::Hooks::EndOfScope 0.12;
 use List::Util qw( first );
@@ -125,9 +123,15 @@ use namespace::clean 0.20;
 #pod
 #pod =head1 SEE ALSO
 #pod
-#pod L<namespace::clean>
-#pod
-#pod L<B::Hooks::EndOfScope>
+#pod =for :list
+#pod * L<namespace::clean>
+#pod * L<B::Hooks::EndOfScope>
+#pod * L<namespace::sweep>
+#pod * L<Sub::Exporter::ForMethods>
+#pod * L<Sub::Name>
+#pod * L<Sub::Install>
+#pod * L<Test::CleanNamespaces>
+#pod * L<Dist::Zilla::Plugin::Test::CleanNamespaces>
 #pod
 #pod =cut
 
@@ -184,7 +188,9 @@ sub _method_check {
         my %methods = map { $_ => 1 } $meta->get_method_list;
         $methods{meta} = 1
           if $meta->isa('Moose::Meta::Role') && Moose->VERSION < 0.90;
-        return sub { $_[0] =~ /^\(/ || $methods{$_[0]} };
+        return Moose->VERSION > 2.1300
+            ? sub { $methods{$_[0]} }
+            : sub { $_[0] =~ /^\(/ || $methods{$_[0]} };
     }
     else {
         my $does = $package->can('does') ? 'does'
@@ -196,7 +202,8 @@ sub _method_check {
             my $coderef = do { no strict 'refs'; \&{ $package . '::' . $_[0] } };
             my $code_stash = Sub::Identify::stash_name($coderef);
             return 1 if $code_stash eq $package;
-            return 1 if $does && $package->$does($code_stash);
+            return 1 if $code_stash eq 'constant';
+            return 1 if $does && eval { $package->$does($code_stash) };
             return 0;
         };
     }
@@ -214,6 +221,10 @@ __END__
 
 namespace::autoclean - Keep imports out of your namespace
 
+=head1 VERSION
+
+version 0.21
+
 =head1 SYNOPSIS
 
     package Foo;
@@ -326,56 +337,46 @@ work correctly for methods from roles consumed at compile time.
 
 =head1 SEE ALSO
 
-L<namespace::clean>
-
-L<B::Hooks::EndOfScope>
-
-=head1 AUTHOR
-
-Florian Ragwitz <rafl@debian.org>
-
-=head1 CONTRIBUTORS
-
 =over 4
 
 =item *
 
-Andrew Rodland <andrew@hbslabs.com>
+L<namespace::clean>
 
 =item *
 
-Chris Prather <cprather@hdpublishing.com>
+L<B::Hooks::EndOfScope>
 
 =item *
 
-Dave Rolsky <autarch@urth.org>
+L<namespace::sweep>
 
 =item *
 
-Felix Ostmann <sadrak@sadrak-laptop.(none)>
+L<Sub::Exporter::ForMethods>
 
 =item *
 
-Graham Knop <haarg@haarg.org>
+L<Sub::Name>
 
 =item *
 
-Karen Etheridge <ether@cpan.org>
+L<Sub::Install>
 
 =item *
 
-Kent Fredric <kentfredric@gmail.com>
+L<Test::CleanNamespaces>
 
 =item *
 
-Shawn M Moore <sartak@gmail.com>
-
-=item *
-
-Tomas Doran <bobtfish@bobtfish.net>
+L<Dist::Zilla::Plugin::Test::CleanNamespaces>
 
 =back
 
+=head1 AUTHOR
+
+Florian Ragwitz <rafl@debian.org>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2009 by Florian Ragwitz.
@@ -383,4 +384,48 @@ This software is copyright (c) 2009 by Florian Ragwitz.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 CONTRIBUTORS
+
+=for stopwords Karen Etheridge Graham Knop Dave Rolsky Kent Fredric Tomas Doran Shawn M Moore Felix Ostmann Chris Prather Andrew Rodland
+
+=over 4
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Graham Knop <haarg@haarg.org>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Kent Fredric <kentfredric@gmail.com>
+
+=item *
+
+Tomas Doran <bobtfish@bobtfish.net>
+
+=item *
+
+Shawn M Moore <sartak@gmail.com>
+
+=item *
+
+Felix Ostmann <sadrak@sadrak-laptop.(none)>
+
+=item *
+
+Chris Prather <cprather@hdpublishing.com>
+
+=item *
+
+Andrew Rodland <andrew@hbslabs.com>
+
+=back
+
 =cut
